package com.game.business.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.game.business.mapper.AppGameCommissionMapper;
import com.game.business.domain.AppGameCommission;
import com.game.business.service.IAppGameCommissionService;
import com.game.common.annotation.DataSource;
import com.game.common.enums.DataSourceType;

/**
 * 游戏佣金配置Service业务层处理
 *
 * @author game
 * @date 2024-06-23
 */
@Service
public class AppGameCommissionServiceImpl extends ServiceImpl<AppGameCommissionMapper, AppGameCommission> implements IAppGameCommissionService {
    @Autowired
    private AppGameCommissionMapper appGameCommissionMapper;

    /**
     * 查询游戏佣金配置
     *
     * @param id 游戏佣金配置主键
     * @return 游戏佣金配置
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public AppGameCommission selectAppGameCommissionById(Long id) {
        return appGameCommissionMapper.selectAppGameCommissionById(id);
    }

    /**
     * 查询游戏佣金配置列表
     *
     * @param appGameCommission 游戏佣金配置
     * @return 游戏佣金配置
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public List<AppGameCommission> selectAppGameCommissionList(AppGameCommission appGameCommission) {
        return appGameCommissionMapper.selectAppGameCommissionList(appGameCommission);
    }

    /**
     * 新增游戏佣金配置
     *
     * @param appGameCommission 游戏佣金配置
     * @return 结果
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public int insertAppGameCommission(AppGameCommission appGameCommission) {
            return appGameCommissionMapper.insertAppGameCommission(appGameCommission);
    }

    /**
     * 修改游戏佣金配置
     *
     * @param appGameCommission 游戏佣金配置
     * @return 结果
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public int updateAppGameCommission(AppGameCommission appGameCommission) {
        return appGameCommissionMapper.updateAppGameCommission(appGameCommission);
    }

    /**
     * 批量删除游戏佣金配置
     *
     * @param ids 需要删除的游戏佣金配置主键
     * @return 结果
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public int deleteAppGameCommissionByIds(Long[] ids) {
        return appGameCommissionMapper.deleteAppGameCommissionByIds(ids);
    }

    /**
     * 删除游戏佣金配置信息
     *
     * @param id 游戏佣金配置主键
     * @return 结果
     */
    @Override
    @DataSource(DataSourceType.SLAVE)
    public int deleteAppGameCommissionById(Long id) {
        return appGameCommissionMapper.deleteAppGameCommissionById(id);
    }
}